# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallIndividualRulesConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_leakage': 'GenerativefirewallDataLeakageRuleConfig',
        'off_topic': 'GenerativefirewallOffTopicRuleConfig',
        'denial_of_service': 'GenerativefirewallDenialOfServiceRuleConfig',
        'consistency_with_knowledgebase': 'GenerativefirewallConsistencyWithKnowledgebaseRuleConfig',
        'indirect_prompt_injection': 'GenerativefirewallIndirectPromptInjectionRuleConfig',
        'pii_detection_input': 'GenerativefirewallPiiDetectionRuleConfig',
        'pii_detection_output': 'GenerativefirewallPiiDetectionRuleConfig'
    }

    attribute_map = {
        'data_leakage': 'dataLeakage',
        'off_topic': 'offTopic',
        'denial_of_service': 'denialOfService',
        'consistency_with_knowledgebase': 'consistencyWithKnowledgebase',
        'indirect_prompt_injection': 'indirectPromptInjection',
        'pii_detection_input': 'piiDetectionInput',
        'pii_detection_output': 'piiDetectionOutput'
    }

    def __init__(self, data_leakage=None, off_topic=None, denial_of_service=None, consistency_with_knowledgebase=None, indirect_prompt_injection=None, pii_detection_input=None, pii_detection_output=None):  # noqa: E501
        """GenerativefirewallIndividualRulesConfig - a model defined in Swagger"""  # noqa: E501
        self._data_leakage = None
        self._off_topic = None
        self._denial_of_service = None
        self._consistency_with_knowledgebase = None
        self._indirect_prompt_injection = None
        self._pii_detection_input = None
        self._pii_detection_output = None
        self.discriminator = None
        if data_leakage is not None:
            self.data_leakage = data_leakage
        if off_topic is not None:
            self.off_topic = off_topic
        if denial_of_service is not None:
            self.denial_of_service = denial_of_service
        if consistency_with_knowledgebase is not None:
            self.consistency_with_knowledgebase = consistency_with_knowledgebase
        if indirect_prompt_injection is not None:
            self.indirect_prompt_injection = indirect_prompt_injection
        if pii_detection_input is not None:
            self.pii_detection_input = pii_detection_input
        if pii_detection_output is not None:
            self.pii_detection_output = pii_detection_output

    @property
    def data_leakage(self):
        """Gets the data_leakage of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The data_leakage of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallDataLeakageRuleConfig
        """
        return self._data_leakage

    @data_leakage.setter
    def data_leakage(self, data_leakage):
        """Sets the data_leakage of this GenerativefirewallIndividualRulesConfig.


        :param data_leakage: The data_leakage of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallDataLeakageRuleConfig
        """

        self._data_leakage = data_leakage

    @property
    def off_topic(self):
        """Gets the off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallOffTopicRuleConfig
        """
        return self._off_topic

    @off_topic.setter
    def off_topic(self, off_topic):
        """Sets the off_topic of this GenerativefirewallIndividualRulesConfig.


        :param off_topic: The off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallOffTopicRuleConfig
        """

        self._off_topic = off_topic

    @property
    def denial_of_service(self):
        """Gets the denial_of_service of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The denial_of_service of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallDenialOfServiceRuleConfig
        """
        return self._denial_of_service

    @denial_of_service.setter
    def denial_of_service(self, denial_of_service):
        """Sets the denial_of_service of this GenerativefirewallIndividualRulesConfig.


        :param denial_of_service: The denial_of_service of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallDenialOfServiceRuleConfig
        """

        self._denial_of_service = denial_of_service

    @property
    def consistency_with_knowledgebase(self):
        """Gets the consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallConsistencyWithKnowledgebaseRuleConfig
        """
        return self._consistency_with_knowledgebase

    @consistency_with_knowledgebase.setter
    def consistency_with_knowledgebase(self, consistency_with_knowledgebase):
        """Sets the consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.


        :param consistency_with_knowledgebase: The consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallConsistencyWithKnowledgebaseRuleConfig
        """

        self._consistency_with_knowledgebase = consistency_with_knowledgebase

    @property
    def indirect_prompt_injection(self):
        """Gets the indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallIndirectPromptInjectionRuleConfig
        """
        return self._indirect_prompt_injection

    @indirect_prompt_injection.setter
    def indirect_prompt_injection(self, indirect_prompt_injection):
        """Sets the indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.


        :param indirect_prompt_injection: The indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallIndirectPromptInjectionRuleConfig
        """

        self._indirect_prompt_injection = indirect_prompt_injection

    @property
    def pii_detection_input(self):
        """Gets the pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallPiiDetectionRuleConfig
        """
        return self._pii_detection_input

    @pii_detection_input.setter
    def pii_detection_input(self, pii_detection_input):
        """Sets the pii_detection_input of this GenerativefirewallIndividualRulesConfig.


        :param pii_detection_input: The pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallPiiDetectionRuleConfig
        """

        self._pii_detection_input = pii_detection_input

    @property
    def pii_detection_output(self):
        """Gets the pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallPiiDetectionRuleConfig
        """
        return self._pii_detection_output

    @pii_detection_output.setter
    def pii_detection_output(self, pii_detection_output):
        """Sets the pii_detection_output of this GenerativefirewallIndividualRulesConfig.


        :param pii_detection_output: The pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallPiiDetectionRuleConfig
        """

        self._pii_detection_output = pii_detection_output

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallIndividualRulesConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallIndividualRulesConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SchemadatacollectorPrediction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'datapoint_id': 'RimeUUID',
        'model_id': 'RimeUUID',
        'data_stream_id': 'RimeUUID',
        'prediction': 'str',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'datapoint_id': 'datapointId',
        'model_id': 'modelId',
        'data_stream_id': 'dataStreamId',
        'prediction': 'prediction',
        'timestamp': 'timestamp'
    }

    def __init__(self, datapoint_id=None, model_id=None, data_stream_id=None, prediction=None, timestamp=None):  # noqa: E501
        """SchemadatacollectorPrediction - a model defined in Swagger"""  # noqa: E501
        self._datapoint_id = None
        self._model_id = None
        self._data_stream_id = None
        self._prediction = None
        self._timestamp = None
        self.discriminator = None
        if datapoint_id is not None:
            self.datapoint_id = datapoint_id
        if model_id is not None:
            self.model_id = model_id
        if data_stream_id is not None:
            self.data_stream_id = data_stream_id
        if prediction is not None:
            self.prediction = prediction
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def datapoint_id(self):
        """Gets the datapoint_id of this SchemadatacollectorPrediction.  # noqa: E501


        :return: The datapoint_id of this SchemadatacollectorPrediction.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._datapoint_id

    @datapoint_id.setter
    def datapoint_id(self, datapoint_id):
        """Sets the datapoint_id of this SchemadatacollectorPrediction.


        :param datapoint_id: The datapoint_id of this SchemadatacollectorPrediction.  # noqa: E501
        :type: RimeUUID
        """

        self._datapoint_id = datapoint_id

    @property
    def model_id(self):
        """Gets the model_id of this SchemadatacollectorPrediction.  # noqa: E501


        :return: The model_id of this SchemadatacollectorPrediction.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this SchemadatacollectorPrediction.


        :param model_id: The model_id of this SchemadatacollectorPrediction.  # noqa: E501
        :type: RimeUUID
        """

        self._model_id = model_id

    @property
    def data_stream_id(self):
        """Gets the data_stream_id of this SchemadatacollectorPrediction.  # noqa: E501


        :return: The data_stream_id of this SchemadatacollectorPrediction.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._data_stream_id

    @data_stream_id.setter
    def data_stream_id(self, data_stream_id):
        """Sets the data_stream_id of this SchemadatacollectorPrediction.


        :param data_stream_id: The data_stream_id of this SchemadatacollectorPrediction.  # noqa: E501
        :type: RimeUUID
        """

        self._data_stream_id = data_stream_id

    @property
    def prediction(self):
        """Gets the prediction of this SchemadatacollectorPrediction.  # noqa: E501


        :return: The prediction of this SchemadatacollectorPrediction.  # noqa: E501
        :rtype: str
        """
        return self._prediction

    @prediction.setter
    def prediction(self, prediction):
        """Sets the prediction of this SchemadatacollectorPrediction.


        :param prediction: The prediction of this SchemadatacollectorPrediction.  # noqa: E501
        :type: str
        """

        self._prediction = prediction

    @property
    def timestamp(self):
        """Gets the timestamp of this SchemadatacollectorPrediction.  # noqa: E501

        The timestamp of the datapoint is stored in the prediction for fast querying.  # noqa: E501

        :return: The timestamp of this SchemadatacollectorPrediction.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this SchemadatacollectorPrediction.

        The timestamp of the datapoint is stored in the prediction for fast querying.  # noqa: E501

        :param timestamp: The timestamp of this SchemadatacollectorPrediction.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SchemadatacollectorPrediction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchemadatacollectorPrediction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallRuleOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rule_name': 'str',
        'action': 'GenerativefirewallFirewallAction',
        'risk_category': 'RiskscoreRiskCategoryType'
    }

    attribute_map = {
        'rule_name': 'ruleName',
        'action': 'action',
        'risk_category': 'riskCategory'
    }

    def __init__(self, rule_name=None, action=None, risk_category=None):  # noqa: E501
        """GenerativefirewallRuleOutput - a model defined in Swagger"""  # noqa: E501
        self._rule_name = None
        self._action = None
        self._risk_category = None
        self.discriminator = None
        if rule_name is not None:
            self.rule_name = rule_name
        if action is not None:
            self.action = action
        if risk_category is not None:
            self.risk_category = risk_category

    @property
    def rule_name(self):
        """Gets the rule_name of this GenerativefirewallRuleOutput.  # noqa: E501


        :return: The rule_name of this GenerativefirewallRuleOutput.  # noqa: E501
        :rtype: str
        """
        return self._rule_name

    @rule_name.setter
    def rule_name(self, rule_name):
        """Sets the rule_name of this GenerativefirewallRuleOutput.


        :param rule_name: The rule_name of this GenerativefirewallRuleOutput.  # noqa: E501
        :type: str
        """

        self._rule_name = rule_name

    @property
    def action(self):
        """Gets the action of this GenerativefirewallRuleOutput.  # noqa: E501


        :return: The action of this GenerativefirewallRuleOutput.  # noqa: E501
        :rtype: GenerativefirewallFirewallAction
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this GenerativefirewallRuleOutput.


        :param action: The action of this GenerativefirewallRuleOutput.  # noqa: E501
        :type: GenerativefirewallFirewallAction
        """

        self._action = action

    @property
    def risk_category(self):
        """Gets the risk_category of this GenerativefirewallRuleOutput.  # noqa: E501


        :return: The risk_category of this GenerativefirewallRuleOutput.  # noqa: E501
        :rtype: RiskscoreRiskCategoryType
        """
        return self._risk_category

    @risk_category.setter
    def risk_category(self, risk_category):
        """Sets the risk_category of this GenerativefirewallRuleOutput.


        :param risk_category: The risk_category of this GenerativefirewallRuleOutput.  # noqa: E501
        :type: RiskscoreRiskCategoryType
        """

        self._risk_category = risk_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallRuleOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallRuleOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
